window.Gleam.initSearch([{"doc":"glenv","title":"glenv","content":"# glenv\n\n[![Package Version](https://img.shields.io/hexpm/v/glenv)](https://hex.pm/packages/glenv)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glenv/)\n\nType-safe environment variables for Gleam.\n\nAccessing environment variables doesn&#39;t give us the type of safety guarantees we&#39;d like in a langauge like Gleam. glenv aims to guarantee that each environment variable is of the correct type AND is present.\n\n```sh\ngleam add glenv\n```\n```gleam\nimport dot_env\nimport gleam/decode\nimport glenv\n\npub type MyEnv {\n  MyEnv(hello: String, foo: Float, count: Int, is_on: Bool)\n}\n\npub fn main() {\n  // Optional: Load environment variables from a file\n  dot_env.load_default()\n\n  let definitions = [\n    #(&quot;HELLO&quot;, glenv.String),\n    #(&quot;FOO&quot;, glenv.Float),\n    #(&quot;COUNT&quot;, glenv.Int),\n    #(&quot;IS_ON&quot;, glenv.Bool),\n  ]\n\n  let decoder =\n    decode.into({\n      use hello &lt;- decode.parameter\n      use foo &lt;- decode.parameter\n      use count &lt;- decode.parameter\n      use is_on &lt;- decode.parameter\n\n      MyEnv(hello: hello, foo: foo, count: count, is_on: is_on)\n    })\n    |&gt; decode.field(&quot;HELLO&quot;, decode.string)\n    |&gt; decode.field(&quot;FOO&quot;, decode.float)\n    |&gt; decode.field(&quot;COUNT&quot;, decode.int)\n    |&gt; decode.field(&quot;IS_ON&quot;, decode.bool)\n\n  let assert Ok(env) = glenv.load(decoder, definitions)\n\n  env.hello == &quot;hello&quot;\n  env.foo == 1.0\n  env.count == 1\n  env.is_on == True\n}\n```\n\n## Expected values\n\n### Bool\n\nAny casing of `true`, `yes` or `1` will be parsed as `True`. Any other value will be parsed as `False`.\n\n### Float\n\nAny value that can be parsed as a float will be parsed as a float. Any other value will result in an `InvalidEnvValue` error.\n\n### Int\n\nAny value that can be parsed as an int will be parsed as an int. Any other value will result in an `InvalidEnvValue` error.\n\n### String\n\nAny value will be parsed as a string.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glenv&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"glenv","title":"Definition","content":"pub type Definition =\n  #(String, Type)\n Definition represents a single environment variable, from key to type.\n\nSynonyms:\nglenv.Definition\nglenv Definition","url":"glenv.html#Definition"},{"doc":"glenv","title":"EnvError","content":"pub type EnvError {\n  NotFoundError(key: String)\n  ParseError(key: String, expected: Type)\n  DefinitionMismatchError(errors: List(dynamic.DecodeError))\n}\n EnvError represents an error that can occur when loading the environment.\nNotFoundError(key: String)\n The key was not found in the environment.\n\nParseError(key: String, expected: Type)\n The key was found in the environment but the value was not of the expected type.\n\nDefinitionMismatchError(errors: List(dynamic.DecodeError))\n The key was found in the environment of the correct type, but the provided definition did not match.\n\nSynonyms:\nglenv.EnvError\nglenv EnvError","url":"glenv.html#EnvError"},{"doc":"glenv","title":"Type","content":"pub type Type {\n  Bool\n  Float\n  Int\n  String\n}\n Type represents the type of an environment variable.\n This dictates how the environment variable is parsed.\nBool\n Boolean type, represented by any casing of &quot;true&quot;, &quot;yes&quot;, or &quot;1&quot;.\n\nFloat\n Float type, represented by values like &quot;1.0&quot; or &quot;1.000&quot;.\n\nInt\n Integer type, represented by values like &quot;1&quot; or &quot;100&quot;.\n\nString\n String type, represented by any value.\n\nSynonyms:\nglenv.Type\nglenv Type","url":"glenv.html#Type"},{"doc":"glenv","title":"load","content":"pub fn load(\n  decoder: Decoder(a),\n  definitions: List(#(String, Type)),\n) -&gt; Result(a, EnvError)\n Load parses the environment variables and returns a Result containing the environment.\n Takes a decoder from the gleam/decode library and a list of definitions.\n \n ## Examples\n\n \n type Env {\n   Env(hello: String, foo: Float, count: Int, is_on: Bool)\n }\n\n let definitions = [\n   #(&quot;HELLO&quot;, glenv.String),\n   #(&quot;FOO&quot;, glenv.Float),\n   #(&quot;COUNT&quot;, glenv.Int),\n   #(&quot;IS_ON&quot;, glenv.Bool),\n ]\n\n let decoder =\n   decode.into({\n     use hello &lt;- decode.parameter\n     use foo &lt;- decode.parameter\n     use count &lt;- decode.parameter\n     use is_on &lt;- decode.parameter\n\n     Env(hello: hello, foo: foo, count: count, is_on: is_on)\n   })\n   |&gt; decode.field(&quot;HELLO&quot;, decode.string)\n   |&gt; decode.field(&quot;FOO&quot;, decode.float)\n   |&gt; decode.field(&quot;COUNT&quot;, decode.int)\n   |&gt; decode.field(&quot;IS_ON&quot;, decode.bool)\n\n let assert Ok(env) = glenv.load(decoder, definitions)\n\n env.hello // &quot;world&quot;\n env.foo // 1.0\n env.count // 1\n env.is_on // True\n \nSynonyms:\nglenv.load\nglenv load","url":"glenv.html#load"},{"doc":"glenv","title":"glenv","content":" glenv is a library for type-sfe environment variable access.\n","url":"glenv.html"}]);